--- title: "wallaroo.records.telemetry_error" type: docs linkTitle: "wallaroo.records.telemetry_error" ---
def from_str(x: Any) -> str:
def to_class(c: Type[~T], x: Any) -> dict:
class WallarooAPIEndpointDefaultError:

The catch all error for telemetry responses.

WallarooAPIEndpointDefaultError(message: str)
@staticmethod
def from_dict( obj: Any) -> wallaroo.records.telemetry_error.WallarooAPIEndpointDefaultError:
def to_dict(self) -> dict:
def wallaroo_api_endpoint_default_error_from_dict( s: Any) -> wallaroo.records.telemetry_error.WallarooAPIEndpointDefaultError:
def wallaroo_api_endpoint_default_error_to_dict( x: wallaroo.records.telemetry_error.WallarooAPIEndpointDefaultError) -> Any: